@@ -5,14 +5,12 @@ from myutils import geo
 R = 6371000
 
 ##########################################################
-def add_lengths(g):
+def add_lengths(g, x, y):
     """Add length to the edges, assuming each vertex has a location"""
-    if 'x' in g.vertex_attributes(): x = 'x'; y = 'y';
-    else: x = 'lon'; y = 'lat';
 
     for i, e in enumerate(g.es()):
-        lon1, lat1 = float(g.vs[e.source][x]), float(g.vs[e.source][y])
-        lon2, lat2 = float(g.vs[e.target][x]), float(g.vs[e.target][y])
+        lon1, lat1 = g.vs[e.source][x], g.vs[e.source][y]
+        lon2, lat2 = g.vs[e.target][x], g.vs[e.target][y]
         g.es[i]['length'] = geo.haversine(lon1, lat1, lon2, lat2)
     return g
 
@@ -29,7 +27,13 @@ def simplify_graphml(graphpath, directed=True, simplify=True):
     g = g.components(mode='weak').giant()
 
     if ('x' in g.vertex_attributes()) or ('lon' in g.vertex_attributes()):
-        g = add_lengths(g)
+        if 'x' in g.vertex_attributes(): x = 'x'; y = 'y';
+        else: x = 'lon'; y = 'lat';
+
+        g.vs[x] = [float(xx) for xx in g.vs[x]]
+        g.vs[y] = [float(yy) for yy in g.vs[y]]
+
+        g = add_lengths(g, xattrib, yattrib)
 
     return g
 
